@@ -12,7 +12,7 @@ from django.http import HttpResponseRedirect
 from django.shortcuts import get_object_or_404
 from django.urls import reverse
 from django.utils.html import format_html
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 try:
     cache = caches['configuration']
@@ -100,10 +100,7 @@ class ConfigurationModelAdmin(admin.ModelAdmin):
 
         return HttpResponseRedirect(
             reverse(
-                'admin:{}_{}_change'.format(
-                    self.model._meta.app_label,
-                    self.model._meta.model_name,
-                ),
+                f"admin:{self.model._meta.app_label}_{self.model._meta.model_name}_change",
                 args=(target.id,),
             )
         )
